==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfField(SpireObject):
    """
    Represents field of the Pdf document's interactive form.
    """

    @property
    def Name(self) -> str:
        """
        Gets the name.
        """
        GetDllLibPdf().PdfField_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Name.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfField_get_Name(self.Ptr))
        return ret

    @property
    def FullName(self) -> str:
        """
        Gets the full name.
        """
        GetDllLibPdf().PdfField_get_FullName.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_FullName.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfField_get_FullName(self.Ptr))
        return ret

    @property
    def Form(self) -> 'PdfForm':
        """
        Gets the form.
        """
        GetDllLibPdf().PdfField_get_Form.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Form.restype = c_void_p
        intPtr = GetDllLibPdf().PdfField_get_Form(self.Ptr)
        ret = None if intPtr == None else PdfForm(intPtr)
        return ret

    @property
    def MappingName(self) -> str:
        """
        Gets or sets the mapping name to be used when exporting interactive form field data from the document.
        """
        GetDllLibPdf().PdfField_get_MappingName.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_MappingName.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfField_get_MappingName(self.Ptr))
        return ret

    @MappingName.setter
    def MappingName(self, value: str):
        GetDllLibPdf().PdfField_set_MappingName.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfField_set_MappingName(self.Ptr, value)

    @property
    def Export(self) -> bool:
        """
        Gets or sets a value indicating whether this field is export.
        """
        GetDllLibPdf().PdfField_get_Export.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Export.restype = c_bool
        ret = GetDllLibPdf().PdfField_get_Export(self.Ptr)
        return ret

    @Export.setter
    def Export(self, value: bool):
        GetDllLibPdf().PdfField_set_Export.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfField_set_Export(self.Ptr, value)

    @property
    def ReadOnly(self) -> bool:
        """
        Gets or sets a value indicating whether the field is read only.
        """
        GetDllLibPdf().PdfField_get_ReadOnly.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_ReadOnly.restype = c_bool
        ret = GetDllLibPdf().PdfField_get_ReadOnly(self.Ptr)
        return ret

    @ReadOnly.setter
    def ReadOnly(self, value: bool):
        GetDllLibPdf().PdfField_set_ReadOnly.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfField_set_ReadOnly(self.Ptr, value)

    @property
    def Required(self) -> bool:
        """
        Gets or sets a value indicating whether this field is required.
        """
        GetDllLibPdf().PdfField_get_Required.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Required.restype = c_bool
        ret = GetDllLibPdf().PdfField_get_Required(self.Ptr)
        return ret

    @Required.setter
    def Required(self, value: bool):
        GetDllLibPdf().PdfField_set_Required.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfField_set_Required(self.Ptr, value)

    @property
    def ToolTip(self) -> str:
        """
        Gets or sets the tool tip.
        """
        GetDllLibPdf().PdfField_get_ToolTip.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_ToolTip.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfField_get_ToolTip(self.Ptr))
        return ret

    @ToolTip.setter
    def ToolTip(self, value: str):
        GetDllLibPdf().PdfField_set_ToolTip.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfField_set_ToolTip(self.Ptr, value)

    @property
    def Page(self) -> 'PdfPageBase':
        """
        Gets the page.
        """
        GetDllLibPdf().PdfField_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Page.restype = c_void_p
        intPtr = GetDllLibPdf().PdfField_get_Page(self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @property
    def Flatten(self) -> bool:
        """
        Gets or sets a value indicating whether this field is flatten.
        """
        GetDllLibPdf().PdfField_get_Flatten.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Flatten.restype = c_bool
        ret = GetDllLibPdf().PdfField_get_Flatten(self.Ptr)
        return ret

    @Flatten.setter
    def Flatten(self, value: bool):
        GetDllLibPdf().PdfField_set_Flatten.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfField_set_Flatten(self.Ptr, value)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfField(SpireObject):
    """
    Represents field of the Pdf document's interactive form.
    """

    @property
    def Name(self) -> str:
        """
        Gets the name.
        """
        GetDllLibPdf().PdfField_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Name.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfField_get_Name,self.Ptr))
        return ret

    @property
    def FullName(self) -> str:
        """
        Gets the full name.
        """
        GetDllLibPdf().PdfField_get_FullName.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_FullName.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfField_get_FullName,self.Ptr))
        return ret

    @property
    def Form(self) -> 'PdfForm':
        """
        Gets the form.
        """
        GetDllLibPdf().PdfField_get_Form.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Form.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfField_get_Form,self.Ptr)
        ret = None if intPtr == None else PdfForm(intPtr)
        return ret

    @property
    def MappingName(self) -> str:
        """
        Gets or sets the mapping name to be used when exporting interactive form field data from the document.
        """
        GetDllLibPdf().PdfField_get_MappingName.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_MappingName.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfField_get_MappingName,self.Ptr))
        return ret

    @MappingName.setter
    def MappingName(self, value: str):
        GetDllLibPdf().PdfField_set_MappingName.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfField_set_MappingName,self.Ptr, value)

    @property
    def Export(self) -> bool:
        """
        Gets or sets a value indicating whether this field is export.
        """
        GetDllLibPdf().PdfField_get_Export.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Export.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfField_get_Export,self.Ptr)
        return ret

    @Export.setter
    def Export(self, value: bool):
        GetDllLibPdf().PdfField_set_Export.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfField_set_Export,self.Ptr, value)

    @property
    def ReadOnly(self) -> bool:
        """
        Gets or sets a value indicating whether the field is read only.
        """
        GetDllLibPdf().PdfField_get_ReadOnly.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_ReadOnly.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfField_get_ReadOnly,self.Ptr)
        return ret

    @ReadOnly.setter
    def ReadOnly(self, value: bool):
        GetDllLibPdf().PdfField_set_ReadOnly.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfField_set_ReadOnly,self.Ptr, value)

    @property
    def Required(self) -> bool:
        """
        Gets or sets a value indicating whether this field is required.
        """
        GetDllLibPdf().PdfField_get_Required.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Required.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfField_get_Required,self.Ptr)
        return ret

    @Required.setter
    def Required(self, value: bool):
        GetDllLibPdf().PdfField_set_Required.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfField_set_Required,self.Ptr, value)

    @property
    def ToolTip(self) -> str:
        """
        Gets or sets the tool tip.
        """
        GetDllLibPdf().PdfField_get_ToolTip.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_ToolTip.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfField_get_ToolTip,self.Ptr))
        return ret

    @ToolTip.setter
    def ToolTip(self, value: str):
        GetDllLibPdf().PdfField_set_ToolTip.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfField_set_ToolTip,self.Ptr, value)

    @property
    def Page(self) -> 'PdfPageBase':
        """
        Gets the page.
        """
        GetDllLibPdf().PdfField_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Page.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfField_get_Page,self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @property
    def Flatten(self) -> bool:
        """
        Gets or sets a value indicating whether this field is flatten.
        """
        GetDllLibPdf().PdfField_get_Flatten.argtypes = [c_void_p]
        GetDllLibPdf().PdfField_get_Flatten.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfField_get_Flatten,self.Ptr)
        return ret

    @Flatten.setter
    def Flatten(self, value: bool):
        GetDllLibPdf().PdfField_set_Flatten.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfField_set_Flatten,self.Ptr, value)
